%define anolis_release 3
%bcond_with manpage
%global crate zram-generator

Name:		rust-%{crate}
Version:	1.1.2
Release:	%{anolis_release}%{?dist}
Summary:	Systemd unit generator for zram swap devices
License:	MIT
URL:		https://crates.io/crates/%{crate}
Source0:	https://github.com/systemd/%{crate}/archive/refs/tags/v%{version}.tar.gz
Source1:        %{crate}-%{version}-vendor.tar.gz
Source2:        zram-generator.conf
Patch001:	0001-add-loongarch64-support-for-linux-raw-sys.patch
Patch002:	0002-add-loongarch64-support-for-nix.patch

BuildRequires: make automake autoconf systemd-rpm-macros
BuildRequires: rust cargo rust-packaging > 21
%if %{with manpage}
BuildRequires: /usr/bin/ronn
%endif
%ifarch loongarch64
BuildRequires: cargo-vendored-libc
%endif

%description
This generator provides a simple and fast mechanism to configure
swap on /dev/zram* devices. The main use case is create swap devices,
but devices with a file system can be created too.

%package 	-n zram-generator
Summary:	Systemd unit generator for zram swap devices

%description 	-n zram-generator
This package provides systemd unit generator for zram swap devices.

%package 	-n zram-generator-defaults
Summary:        Default configuration for zram-generator
Requires:       zram-generator = %{version}-%{release}
Obsoletes:      zram < 0.4-2
BuildArch:      noarch

%description 	-n zram-generator-defaults
This package provides default configuration for zram-generator.

%prep
%setup -q -n %{crate}-%{version}
%setup -q -D -T -a 1 -n %{crate}-%{version}
cp -pva  %{SOURCE2} .

%cargo_prep
mkdir -p .cargo
cat > .cargo/config <<EOF
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"
EOF

%ifarch loongarch64
rm -rf vendor/libc
cp -r /usr/share/cargo/vendor/libc vendor/
%patch001 -p1
%patch002 -p1
%endif

%build
export SYSTEMD_UTIL_DIR=%{_systemd_util_dir}
export LC_ALL=C.UTF-8
%cargo_build
%make_build SYSTEMD_SYSTEM_UNIT_DIR=%{_unitdir} \
  SYSTEMD_SYSTEM_GENERATOR_DIR=%{_systemdgeneratordir} \
%if %{with manpage}
  man \
%endif
  systemd-service

%install
export SYSTEMD_UTIL_DIR=%{_systemd_util_dir}
%cargo_install

%make_install SYSTEMD_SYSTEM_UNIT_DIR=%{_unitdir} \
  SYSTEMD_SYSTEM_GENERATOR_DIR=%{_systemdgeneratordir} \
  NOBUILD=1 %{!?with_manpage:NOMAN=1}

mkdir -p %{buildroot}%{_prefix}/lib/systemd
install -p -m 0644 %{SOURCE2} %{buildroot}%{_prefix}/lib/systemd

# Remove devel files because we do not provide devel sub-package currently.
rm -rf %{buildroot}%{crate_instdir}

%check
export SYSTEMD_UTIL_DIR=%{_systemd_util_dir}
%cargo_test

%files		-n zram-generator
%{_systemdgeneratordir}/zram-generator
%{_unitdir}/systemd-zram-setup@.service
%if %{with manpage}
%{_mandir}/man8/zram-generator.8*
%{_mandir}/man5/zram-generator.conf.5*
%endif
%doc README.md zram-generator.conf.example
%license LICENSE

%files 		-n zram-generator-defaults
%{_prefix}/lib/systemd/zram-generator.conf

%changelog
* Tue Nov 14 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 1.1.2-3
- add loongarch64 support for rust-zram-generator

* Sat Apr 15 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.1.2-2
- Refactor the specfile and remove devel sub-package
- Disable manpage generation by default

* Wed Apr 20 2022 happy_orange <songnannan@linux.alibaba.com> - 1.1.2-1
- Init package from upstream
